@@ -4,7 +4,7 @@ use File::Path 'mkpath';
 use File::Copy 'copy';
 use Config;
 
-my $VERSION = '1.02';			# Changelog at end
+my $VERSION = '1.03';			# Changelog at end
 die "Debugging cycle detected"		# set to -1 to allow extra iteration
   if ++$ENV{PERL_DEBUG_MCODE_CYCLE} > 1;
 
@@ -66,9 +66,8 @@ $bd .= ($opt{O} || '');
 my ($chk_module) = (shift);
 
 sub report_Makefile ($) {
-  my $f = shift;
+  my($f, $in) = shift;
   print STDERR "# reporting $f header:\n# ==========================\n";
-  my ($base_d, $in) = (-f "t/sinl.t" ? '.' : '..', '');
   open M, "< $f" or die "Can't open $f";
   $in = <M> while defined $in and $in !~ /MakeMaker \s+ Parameters/xi;
   $in = <M>;
@@ -133,8 +132,8 @@ my $gdb = `gdb --version` unless $opt{d};
 my $dbx = `dbx -V -c quit` unless $gdb;
 unless ($gdb or $dbx) {
   unless ($gdb = `gdb --version`) {
-    my @cand;
-    for my $dir (split m(/), ($ENV{PATH} || '')) {
+    my($sep, @cand) = quotemeta $Config{path_sep};
+    for my $dir (split m($sep), ($ENV{PATH} || '')) {
       for my $f (<$dir/*>) {
         push @cand, $f if $f =~ m{dbx|gdb|lldb}i and -x $f;
       }
@@ -151,11 +150,13 @@ sub report_no_debugger () {
     unless $gdb or $dbx =~ /\b dbx \s+ debugger \b/xi;
 }
 
-my $postpone = not (defined $gdb or defined $dbx);
+$@ = '';
+eval {report_no_debugger() };
+my $postpone = ( eval {report_no_debugger(); 1 } ? '' : "$@" );
 if ($opt{B}) {
   warn "No debugger found.  Nevertheless, I build a new version per -B switch." if $postpone;
 } else {
-  report_no_debugger();
+  die $postpone if $postpone;
 }
 
 die "Directory $bd exist; won't overwrite" if -d $bd;
@@ -200,13 +201,14 @@ my $make = $Config{make};
 $make = 'make' unless defined $make;
 system $make and die "system($make): rc=$?";
 
-report_no_debugger();		# Reached without a debugger only with -B
+die $postpone if $postpone;	# Reached without a debugger only with -B
 
 my $p = ($^X =~ m([\\/]) ? $^X : `which perl`) || $^X;
 chomp $p unless $p eq $^X;
 my(@cmd, $ver);
 
 for my $script (@ARGV) {
+  $script = "../$script" if not -f $script and -f "../$script";
   if ($gdb) {
     $ver = $gdb;
     my $gdb_in = 'gdb-in';
@@ -239,6 +241,7 @@ echo \\n=====================================\\n\\n
 disassemble /m
 echo \\n=====================================\\n\\n
 ${extra}info sharedlibrary
+echo \\n=====================================\\n\\n
 ${proc}quit
 EOP
     close TT or die "Can't close $gdb_in for write: $!";
@@ -283,4 +286,9 @@ __END__
 	On newer Perls %Config::Config may be read-only.
 	Move gdb report of /proc to the end (not working on cygwin 2016, gdb v7.8)
 1.02	Scan and report possible candidates for a debugger.
-	New option -B.
\ No newline at end of file
+	New option -B.
+1.03	Misprint fixed in splitting $ENV{PATH}.
+	Report candidates in more situations.
+	Remove unused code.
+	May try to open (failing) scripts in ../ (happens with Math::Pari if the build in a subdirectory "finds" a different version).
+		XXX Propagate flags for Makefile.PL???
\ No newline at end of file
